pub struct EventFlag(/* private fields */);Implementations
Sourceimpl EventFlag
impl EventFlag
pub const EV_ADD: EventFlag
pub const EV_DELETE: EventFlag
pub const EV_ENABLE: EventFlag
pub const EV_DISABLE: EventFlag
pub const EV_UDATA_SPECIFIC: EventFlag
pub const EV_ONESHOT: EventFlag
pub const EV_CLEAR: EventFlag
pub const EV_RECEIPT: EventFlag
pub const EV_DISPATCH: EventFlag
pub const EV_SYSFLAGS: EventFlag
pub const EV_FLAG0: EventFlag
pub const EV_FLAG1: EventFlag
pub const EV_EOF: EventFlag
pub const EV_ERROR: EventFlag
Sourceimpl EventFlag
impl EventFlag
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<EventFlag>
pub const fn from_bits(bits: u16) -> Option<EventFlag>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> EventFlag
pub const fn from_bits_truncate(bits: u16) -> EventFlag
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> EventFlag
pub const fn from_bits_retain(bits: u16) -> EventFlag
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<EventFlag>
pub fn from_name(name: &str) -> Option<EventFlag>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: EventFlag) -> bool
pub const fn intersects(&self, other: EventFlag) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: EventFlag) -> bool
pub const fn contains(&self, other: EventFlag) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: EventFlag)
pub fn remove(&mut self, other: EventFlag)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: EventFlag)
pub fn toggle(&mut self, other: EventFlag)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: EventFlag, value: bool)
pub fn set(&mut self, other: EventFlag, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: EventFlag) -> EventFlag
pub const fn intersection(self, other: EventFlag) -> EventFlag
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: EventFlag) -> EventFlag
pub const fn union(self, other: EventFlag) -> EventFlag
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: EventFlag) -> EventFlag
pub const fn difference(self, other: EventFlag) -> EventFlag
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: EventFlag) -> EventFlag
pub const fn symmetric_difference(self, other: EventFlag) -> EventFlag
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> EventFlag
pub const fn complement(self) -> EventFlag
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EventFlag
impl EventFlag
Sourcepub const fn iter(&self) -> Iter<EventFlag>
pub const fn iter(&self) -> Iter<EventFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventFlag>
pub const fn iter_names(&self) -> IterNames<EventFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.